==> libgtk-java-2.7.0.tar.bz2: libgtk-java-2.7.0/src/java/org/gnu/gtk/TextChildAnchor.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import org.gnu.glib.GObject;
import org.gnu.glib.Type;
import org.gnu.javagnome.Handle;
/**
 * An anchor for embedding widgets within TextView widgets.
 * You would usually only use the methods of {@link TextView} to sort out Child
 * widgets.
 */
public class TextChildAnchor extends GObject 
{

	/**
	 * Constructs a new TextChildAnchor.
	 */
	public TextChildAnchor(){
		super(gtk_text_child_anchor_new ());
	}

	public TextChildAnchor(Handle handle)  {
		super(handle);
	}
    
    public static TextChildAnchor getTextChildAnchor(Handle handle) {
        if (handle == null)
            return null;
        
        TextChildAnchor obj = (TextChildAnchor) getGObjectFromHandle(handle);
        if (obj == null)
            obj = new TextChildAnchor(handle);
        
        return obj;
    }

	/**
	 * Returns the associated widget
	 */
	public Widget getWidget(){
	    Handle hndl = gtk_text_child_anchor_get_widgets(getHandle());
		return Widget.getWidget(hndl);
	}

	/**
	 * Returns true if the anchor has been deleted from the textbuffer.
	 */
	public boolean getDeleted(){
		return gtk_text_child_anchor_get_deleted(getHandle());
	}

	/**
	 * Retrieve the runtime type used by the GLib library.
	 */
	public static Type getType() {
		return new Type(gtk_text_child_anchor_get_type());
	}

    native static final protected int gtk_text_child_anchor_get_type ();
    native static final protected Handle gtk_text_child_anchor_new ();
    native static final protected Handle gtk_text_child_anchor_get_widgets (Handle anchor);
    native static final protected boolean gtk_text_child_anchor_get_deleted (Handle anchor);
}

==> libgtk-java-2.8.1.tar.bz2: libgtk-java-2.8.1/src/java/org/gnu/gtk/TextChildAnchor.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import org.gnu.glib.GObject;
import org.gnu.glib.Type;
import org.gnu.glib.Handle;
/**
 * An anchor for embedding widgets within TextView widgets.
 * You would usually only use the methods of {@link TextView} to sort out Child
 * widgets.
 */
public class TextChildAnchor extends GObject 
{

	/**
	 * Constructs a new TextChildAnchor.
	 */
	public TextChildAnchor(){
		super(gtk_text_child_anchor_new ());
	}

	public TextChildAnchor(Handle handle)  {
		super(handle);
	}
    
    /**
     * Internal static factory method to be used by Java-Gnome only.
     */
    public static TextChildAnchor getTextChildAnchor(Handle handle) {
        if (handle == null)
            return null;
        
        TextChildAnchor obj = (TextChildAnchor) getGObjectFromHandle(handle);
        if (obj == null)
            obj = new TextChildAnchor(handle);
        
        return obj;
    }

	/**
	 * Returns the associated widget
	 */
	public Widget getWidget(){
	    Handle hndl = gtk_text_child_anchor_get_widgets(getHandle());
		return Widget.getWidget(hndl);
	}

	/**
	 * Returns true if the anchor has been deleted from the textbuffer.
	 */
	public boolean getDeleted(){
		return gtk_text_child_anchor_get_deleted(getHandle());
	}

	/**
	 * Retrieve the runtime type used by the GLib library.
	 */
	public static Type getType() {
		return new Type(gtk_text_child_anchor_get_type());
	}

    native static final protected int gtk_text_child_anchor_get_type ();
    native static final protected Handle gtk_text_child_anchor_new ();
    native static final protected Handle gtk_text_child_anchor_get_widgets (Handle anchor);
    native static final protected boolean gtk_text_child_anchor_get_deleted (Handle anchor);
}
